@@ -28,7 +28,6 @@
 
 #include "ieditor.h"
 #include "iconfigtool.h"
-#include "ikeyboard.h"
 #include "wx/treectrl.h"
 #include "project.h"
 #include "notebook_ex.h"
@@ -39,6 +38,7 @@
 #include "notebook_ex.h"
 #include <vector>
 #include "debugger.h"
+#include "clStatusBar.h"
 
 class TagsManager;
 class Workspace;
@@ -90,6 +90,20 @@ public:
     IManager() {}
     virtual ~IManager() {}
 
+    /**
+     * @brief show the output pane and if provided, select 'selectedWindow'
+     * @param selectWindow tab within the 'Output Pane' to select, if empty don't change
+     * the selection
+     */
+    virtual void ShowOutputPane(const wxString& selectWindow = "") = 0;
+    
+    /**
+     * @brief toggle the output pane
+     * @param selectWindow tab within the 'Output Pane' to select, if empty don't change
+     * the selection
+     */
+    virtual void ToggleOutputPane(const wxString& selectedWindow = "") = 0;
+    
     // return the current editor
     /**
      * @brief return the active editor
@@ -97,6 +111,12 @@ public:
      * editor open
      */
     virtual IEditor* GetActiveEditor() = 0;
+    
+    /**
+     * @brief return the main frame's status bar
+     */
+    virtual clStatusBar* GetStatusBar() = 0;
+    
     /**
      * @brief open file and make it the active editor
      * @param fileName the file to open - use absolute path
@@ -105,7 +125,7 @@ public:
      * @return true if file opened
      */
     virtual bool
-        OpenFile(const wxString& fileName, const wxString& projectName = wxEmptyString, int lineno = wxNOT_FOUND) = 0;
+    OpenFile(const wxString& fileName, const wxString& projectName = wxEmptyString, int lineno = wxNOT_FOUND) = 0;
 
     /**
      * @brief Open file using browsing record
@@ -147,7 +167,7 @@ public:
      * @sa Notebook
      */
     virtual Notebook* GetOutputPaneNotebook() = 0;
-    
+
     /**
      * @brief append text line to the tab in the "Output View"
      */
@@ -157,9 +177,9 @@ public:
      * @brief clear the content of the selected output tab
      */
     virtual void ClearOutputTab(eOutputPaneTab tab) = 0;
-    
+
     virtual wxPanel* GetEditorPaneNotebook() = 0;
-    virtual void AddEditorPage(wxWindow* page, const wxString& name) = 0;
+    virtual void AddEditorPage(wxWindow* page, const wxString& name, const wxString& tooltip = wxEmptyString) = 0;
     virtual wxWindow* GetActivePage() = 0;
     virtual wxWindow* GetPage(size_t page) = 0;
 
@@ -302,11 +322,6 @@ public:
      */
     virtual bool SaveAll() = 0;
 
-    /**
-     * @brief return the keyboard manager
-     */
-    virtual IKeyboard* GetKeyboardManager() = 0;
-
     /**
      * @brief return the editor's settings object
      */
@@ -392,8 +407,15 @@ public:
 
     /**
      * @brief close the named page in the mainbook
+     * @param the tab title.
+     * @note if there are multiple items with this title, all of them will be closed
      */
-    virtual bool ClosePage(const wxString& text) = 0;
+    virtual bool ClosePage(const wxString& title) = 0;
+
+    /**
+     * @brief close an editor with a given file name (full path)
+     */
+    virtual bool ClosePage(const wxFileName& filename) = 0;
 
     /**
      * @brief return named window in mainbook
@@ -403,8 +425,11 @@ public:
     /**
      * @brief add a page to the mainbook
      */
-    virtual bool
-        AddPage(wxWindow* win, const wxString& text, const wxBitmap& bmp = wxNullBitmap, bool selected = false) = 0;
+    virtual bool AddPage(wxWindow* win,
+                         const wxString& text,
+                         const wxString& tooltip = wxEmptyString,
+                         const wxBitmap& bmp = wxNullBitmap,
+                         bool selected = false) = 0;
 
     /**
      * @brief select a window in mainbook
@@ -461,10 +486,18 @@ public:
     virtual size_t GetPageCount() const = 0;
 
     /**
-     * @brief return list of all open editors
+     * @brief return list of all open editors in the main notebook.
+     * This function returns only instances of IEditor (i.e. a file text editor)
      */
     virtual size_t GetAllEditors(IEditor::List_t& editors, bool inOrder = false) = 0;
 
+    /**
+     * @brief return list of open tabs in the main notebook. If you need only editors, use GetAllEditors
+     * @param tabs [output]
+     * @param inOrder retain the editors order
+     */
+    virtual size_t GetAllTabs(clTab::Vec_t& tabs) = 0;
+
     // ---------------------------------------------
     // Breakpoint management
     // ---------------------------------------------
@@ -491,6 +524,21 @@ public:
      */
     virtual void ProcessEditEvent(wxCommandEvent& e, IEditor* editor) = 0;
 
+    /**
+     * @brief add 'fileName' to the list of recently used workspaces
+     * @param fileName
+     */
+    virtual void AddWorkspaceToRecentlyUsedList(const wxFileName& fileName) = 0;
+
+    /**
+     * @brief store a new session for the workspace file associated with the file 'workspaceFile'
+     */
+    virtual void StoreWorkspaceSession(const wxFileName& workspaceFile) = 0;
+
+    /**
+     * @brief load the session associated with 'workspaceFile'
+     */
+    virtual void LoadWorkspaceSession(const wxFileName& workspaceFile) = 0;
     // ----------------------------------------------
     // Perspective management
     // ----------------------------------------------
@@ -506,6 +554,17 @@ public:
      * this function also makes sure that the 'Perspective' menu is updated
      */
     virtual void SavePerspective(const wxString& perspectiveName) = 0;
+
+    // Search
+    /**
+     * @brief open the find in files dialog and select 'path' to search in
+     */
+    virtual void OpenFindInFileForPath(const wxString& path) = 0;
+
+    /**
+     * @brief open the find in files dialog with multiple search paths
+     */
+    virtual void OpenFindInFileForPaths(const wxArrayString& paths) = 0;
 };
 
 #endif // IMANAGER_H
