@@ -61,6 +61,7 @@
 PluginManager* PluginManager::Get()
 {
     static PluginManager theManager;
+    ::clSetManager(&theManager);
     return &theManager;
 }
 
@@ -158,6 +159,14 @@ void PluginManager::Load()
             }
 #endif
 
+#ifdef __WXGTK__
+            wxFileName fnDLL(fileName);
+            if(fnDLL.GetFullName().StartsWith("lib")) {
+                // don't attempt to load a library
+                continue;
+            }
+#endif
+
             clDynamicLibrary* dl = new clDynamicLibrary();
             if(!dl->Load(fileName)) {
                 CL_ERROR(wxT("Failed to load plugin's dll: ") + fileName);
@@ -290,7 +299,13 @@ void PluginManager::Load()
     }
 }
 
-IEditor* PluginManager::GetActiveEditor() { return (IEditor*)clMainFrame::Get()->GetMainBook()->GetActiveEditor(true); }
+IEditor* PluginManager::GetActiveEditor()
+{
+    if(clMainFrame::Get() && clMainFrame::Get()->GetMainBook()) {
+        return (IEditor*)clMainFrame::Get()->GetMainBook()->GetActiveEditor(true);
+    }
+    return NULL;
+}
 
 IConfigTool* PluginManager::GetConfigTool() { return EditorConfigST::Get(); }
 
@@ -451,17 +466,8 @@ TagEntryPtr PluginManager::GetTagAtCaret(bool scoped, bool impl)
 
 bool PluginManager::AllowToolbar()
 {
-    long v = EditorConfigST::Get()->GetInteger(wxT("UseSingleToolbar"));
-    if(v != wxNOT_FOUND) {
-        return v ? false : true;
-    } else {
-// entry does not exist
-#ifdef __WXMAC__
-        return false;
-#else
-        return true;
-#endif
-    }
+    long v = EditorConfigST::Get()->GetInteger("UseSingleToolbar", 1);
+    return (v == 1 ? false : true);
 }
 
 void PluginManager::EnableToolbars()
@@ -506,7 +512,7 @@ BuildManager* PluginManager::GetBuildManager() { return BuildManagerST::Get(); }
 BuildSettingsConfig* PluginManager::GetBuildSettingsConfigManager() { return BuildSettingsConfigST::Get(); }
 
 bool PluginManager::ClosePage(const wxString& title) { return clMainFrame::Get()->GetMainBook()->ClosePage(title); }
-bool PluginManager::ClosePage(const wxFileName& filename) 
+bool PluginManager::ClosePage(const wxFileName& filename)
 {
     MainBook* book = clMainFrame::Get()->GetMainBook();
     LEditor* editor = book->FindEditor(filename.GetFullPath());
@@ -515,7 +521,8 @@ bool PluginManager::ClosePage(const wxFileName& filename)
 
 wxWindow* PluginManager::FindPage(const wxString& text) { return clMainFrame::Get()->GetMainBook()->FindPage(text); }
 
-bool PluginManager::AddPage(wxWindow* win, const wxString& text,const wxString& tooltip, const wxBitmap& bmp, bool selected)
+bool
+PluginManager::AddPage(wxWindow* win, const wxString& text, const wxString& tooltip, const wxBitmap& bmp, bool selected)
 {
     return clMainFrame::Get()->GetMainBook()->AddPage(win, text, tooltip, bmp, selected);
 }
@@ -773,13 +780,13 @@ void PluginManager::StoreWorkspaceSession(const wxFileName& workspaceFile)
     }
 }
 
-void PluginManager::LoadWorkspaceSession(const wxFileName& workspaceFile) 
+void PluginManager::LoadWorkspaceSession(const wxFileName& workspaceFile)
 {
     SessionEntry session;
     if(SessionManager::Get().GetSession(workspaceFile.GetFullPath(), session)) {
         clMainFrame::Get()->GetMainBook()->RestoreSession(session);
         // Set this session as the 'Last' session
-        SessionManager::Get().SetLastWorkspaceName(workspaceFile.GetFullPath());
+        SessionManager::Get().SetLastSession(workspaceFile.GetFullPath());
     }
 }
 
@@ -799,10 +806,7 @@ void PluginManager::OpenFindInFileForPaths(const wxArrayString& paths)
     clMainFrame::Get()->GetEventHandler()->AddPendingEvent(ff);
 }
 
-void PluginManager::ShowOutputPane(const wxString& selectedWindow)
-{
-    ManagerST::Get()->ShowOutputPane(selectedWindow);
-}
+void PluginManager::ShowOutputPane(const wxString& selectedWindow) { ManagerST::Get()->ShowOutputPane(selectedWindow); }
 
 size_t PluginManager::GetAllTabs(clTab::Vec_t& tabs)
 {
@@ -810,10 +814,7 @@ size_t PluginManager::GetAllTabs(clTab::Vec_t& tabs)
     return tabs.size();
 }
 
-clStatusBar* PluginManager::GetStatusBar()
-{
-    return static_cast<clStatusBar*>(clMainFrame::Get()->GetStatusBar());
-}
+clStatusBar* PluginManager::GetStatusBar() { return static_cast<clStatusBar*>(clMainFrame::Get()->GetStatusBar()); }
 
 void PluginManager::ToggleOutputPane(const wxString& selectedWindow)
 {
