@@ -10,7 +10,7 @@ public:
     virtual ~EclipseCSSThemeImporter();
 
 public:
-    virtual bool Import(const wxFileName& eclipseXmlFile);
+    virtual LexerConf::Ptr_t Import(const wxFileName& eclipseXmlFile);
 };
 
 #endif // ECLIPSECSSTHEMEIMPORTER_H
