@@ -16,8 +16,8 @@
 //                                                  F i l e
 //
 //    This program is free software; you can redistribute it and/or modify
-//    it under the terms of the GNU General Public License as published by
-//    the Free Software Foundation; either version 2 of the License, or
+//    it under the terms OF the GNU General Public License as published by
+//    the Free Software Foundation; either version 2 OF the License, or
 //    (at your option) any later version.
 //
 //////////////////////////////////////////////////////////////////////////////
@@ -37,19 +37,20 @@
 #include "event_notifier.h"
 #include "plugin.h"
 #include "ColoursAndFontsManager.h"
+#include "drawingutils.h"
 
 BEGIN_EVENT_TABLE(clEditorTipWindow, wxPanel)
 EVT_PAINT(clEditorTipWindow::OnPaint)
 EVT_ERASE_BACKGROUND(clEditorTipWindow::OnEraseBg)
 END_EVENT_TABLE()
 
-#define TIP_SPACER 4
+#define TIP_SPACER 10
 
 clEditorTipWindow::clEditorTipWindow(wxWindow* parent)
     : wxPanel(parent)
     , m_highlighIndex(0)
 {
-    m_font = ColoursAndFontsManager::Get().GetLexer("c++")->GetFontForSyle(0); // default font
+    m_font = DrawingUtils::GetDefaultFixedFont();
     Hide();
     EventNotifier::Get()->Connect(
         wxEVT_CMD_COLOURS_FONTS_UPDATED, clCommandEventHandler(clEditorTipWindow::OnEditoConfigChanged), NULL, this);
@@ -61,7 +62,10 @@ clEditorTipWindow::~clEditorTipWindow()
         wxEVT_CMD_COLOURS_FONTS_UPDATED, clCommandEventHandler(clEditorTipWindow::OnEditoConfigChanged), NULL, this);
 }
 
-void clEditorTipWindow::OnEraseBg(wxEraseEvent& e) { wxUnusedVar(e); }
+void clEditorTipWindow::OnEraseBg(wxEraseEvent& e)
+{
+    wxUnusedVar(e);
+}
 
 void clEditorTipWindow::OnPaint(wxPaintEvent& e)
 {
@@ -69,17 +73,19 @@ void clEditorTipWindow::OnPaint(wxPaintEvent& e)
     wxBufferedPaintDC dc(this);
 
     wxGCDC gdc;
-    if(!DrawingUtils::GetGCDC(dc, gdc)) return;
-    
+    if(!DrawingUtils::GetGCDC(dc, gdc))
+        return;
+    if(m_args.IsEmpty())
+        return;
+
     // Define the colours used by this tooltip window
-    wxColour bgColour, penColour, textColour, higlighTextBg, higlighTextFg, higlighTextPen;
-    bgColour = wxColour("#feffcd"); // basic colour
-    penColour = bgColour.ChangeLightness(80);
-    textColour = wxColour("#000023");
-    higlighTextBg = wxColour("rgb(204, 153, 0)");
-    higlighTextPen = higlighTextBg;
-    higlighTextFg = *wxWHITE;
-    
+    clColourPalette colours = DrawingUtils::GetColourPalette();
+    wxColour bgColour, penColour, textColour, highlightBgColour, highlightFgColour;
+    bgColour = colours.bgColour;
+    penColour = colours.penColour;
+    textColour = colours.textColour;
+    highlightBgColour = colours.selectionBgColour;
+    highlightFgColour = colours.selecteTextColour;
     wxRect rr = GetClientRect();
 
     // draw the background using the parent background colour
@@ -89,50 +95,63 @@ void clEditorTipWindow::OnPaint(wxPaintEvent& e)
     gdc.SetFont(m_font);
 
     // Highlight the text
-    clCallTipPtr tip = GetTip();
-    int secondLineY = (rr.GetHeight() / 2) + 1;
-    int firstLineY = TIP_SPACER;
-
-    // Draw the Tip text
     gdc.SetTextForeground(textColour);
-    gdc.DrawText(m_tipText, wxPoint(TIP_SPACER, firstLineY));
+    wxSize helperTextSize = gdc.GetTextExtent("Tp");
 
-    if(tip) {
-        bool twoLinesTip = (tip->Count() > 1);
-        wxString txt;
-        if(twoLinesTip) {
-            txt << tip->GetCurr() + 1 << wxT(" of ") << tip->Count();
-            int txtLen = DoGetTextLen(gdc, txt);
+    wxCoord x = TIP_SPACER;
+    wxCoord y = 0;
 
-            int summaryLineXText(rr.GetWidth());
-            summaryLineXText -= (txtLen + TIP_SPACER);
+    if(!m_header.IsEmpty()) {
+        wxFont guiFont = m_font;
+        gdc.SetFont(guiFont);
+        wxSize headerSize = gdc.GetTextExtent(m_header);
+        wxPoint headerPt;
+        headerPt.x = rr.GetWidth() - headerSize.x - TIP_SPACER;
+        headerPt.y = 0;
+        gdc.SetTextForeground(textColour);
+        gdc.DrawText(m_header, headerPt);
+        y += helperTextSize.y;
+        gdc.DrawLine(0, y, rr.GetWidth(), y);
+    }
 
-            // Draw the summary line
+    gdc.SetFont(m_font);
+    for(size_t i = 0; i < m_args.size(); ++i) {
+        wxString line = m_args.Item(i);
+        if((int)i == m_highlighIndex) {
+            // wxFont f = m_font;
+            // f.SetWeight(wxFONTWEIGHT_BOLD);
+            gdc.SetBrush(highlightBgColour);
+            gdc.SetPen(highlightBgColour);
+            gdc.SetTextForeground(highlightFgColour);
+            wxRect selectionRect(0, y, rr.GetWidth(), helperTextSize.y);
+            selectionRect.Deflate(1);
+            gdc.DrawRectangle(selectionRect);
+            gdc.DrawText(line, x, y);
+
+        } else {
             gdc.SetTextForeground(textColour);
-            gdc.DrawText(txt, summaryLineXText, secondLineY + TIP_SPACER / 2);
+            gdc.DrawText(line, x, y);
         }
+        y += helperTextSize.y;
+    }
 
-        int start(-1), len(-1);
-        tip->GetHighlightPos(m_highlighIndex, start, len);
-        if(len != -1 && start != -1) {
-            wxString txtBefore = m_tipText.Mid(0, start);
-            wxString txtInclude = m_tipText.Mid(start, len);
+    if(!m_footer.IsEmpty()) {
+        gdc.SetPen(penColour);
+        gdc.DrawLine(0, y, rr.GetWidth(), y);
 
-            int x = DoGetTextLen(gdc, txtBefore);
-            int w = DoGetTextLen(gdc, txtInclude);
+        // Draw the extra line ("1 OF N")
+        m_footer.Clear();
+        m_footer << (GetTip()->GetCurr() + 1) << " OF " << GetTip()->Count();
 
-            // darken the background colour and use it as the highlight colour
-            gdc.SetBrush(higlighTextBg);
-            gdc.SetPen(higlighTextPen);
-            gdc.SetTextForeground(higlighTextFg);
+        wxFont guiFont = m_font;
+        gdc.SetFont(guiFont);
+        wxSize extraLineSize = gdc.GetTextExtent(m_footer);
 
-            // if this is a 2 liner tip, the highlight rect is 1/2 the tip window height,
-            // otherwise its the same as the height
-            int highlightRectHeight = twoLinesTip ? (rr.GetHeight() / 2) : rr.GetHeight();
-            int highlightRectY = twoLinesTip ? firstLineY - (TIP_SPACER / 2) : 0;
-            gdc.DrawRoundedRectangle(x + TIP_SPACER - 1, highlightRectY, w + 2, highlightRectHeight, 0);
-            gdc.DrawText(txtInclude, wxPoint(x + TIP_SPACER, firstLineY));
-        }
+        wxPoint extraLinePt;
+        extraLinePt.x = rr.GetWidth() - extraLineSize.x - TIP_SPACER;
+        extraLinePt.y = rr.GetHeight() - extraLineSize.y;
+        gdc.SetTextForeground(textColour);
+        gdc.DrawText(m_footer, extraLinePt);
     }
 }
 
@@ -153,12 +172,16 @@ void clEditorTipWindow::AddCallTip(clCallTipPtr tip)
 
 clCallTipPtr clEditorTipWindow::GetTip()
 {
-    if(m_tips.empty()) return NULL;
+    if(m_tips.empty())
+        return NULL;
 
     return m_tips.at(m_tips.size() - 1).tip;
 }
 
-bool clEditorTipWindow::IsEmpty() { return m_tips.empty(); }
+bool clEditorTipWindow::IsEmpty()
+{
+    return m_tips.empty();
+}
 
 void clEditorTipWindow::Remove()
 {
@@ -170,7 +193,8 @@ void clEditorTipWindow::Remove()
         }
     }
 
-    if(m_tips.empty()) Deactivate();
+    if(m_tips.empty())
+        Deactivate();
 }
 
 void clEditorTipWindow::Clear()
@@ -183,13 +207,17 @@ void clEditorTipWindow::Clear()
     m_lineHeight = 0;
 }
 
-bool clEditorTipWindow::IsActive() { return IsShown(); }
+bool clEditorTipWindow::IsActive()
+{
+    return IsShown();
+}
 
 void clEditorTipWindow::Highlight(int argIdxToHilight)
 {
     clCallTipPtr tip = GetTip();
     if(tip) {
         m_tipText = tip->Current();
+        DoMakeMultipleLineTip();
         m_highlighIndex = argIdxToHilight;
         DoLayoutTip();
     } else {
@@ -202,6 +230,7 @@ void clEditorTipWindow::SelectNext(int argIdxToHilight)
     clCallTipPtr tip = GetTip();
     if(tip) {
         m_tipText = tip->Next();
+        DoMakeMultipleLineTip();
         m_highlighIndex = argIdxToHilight;
         DoLayoutTip();
     }
@@ -212,6 +241,7 @@ void clEditorTipWindow::SelectPrev(int argIdxToHilight)
     clCallTipPtr tip = GetTip();
     if(tip) {
         m_tipText = tip->Prev();
+        DoMakeMultipleLineTip();
         m_highlighIndex = argIdxToHilight;
         DoLayoutTip();
     }
@@ -228,7 +258,8 @@ wxString clEditorTipWindow::GetText()
 
 void clEditorTipWindow::Activate(wxPoint pt, int lineHeight, wxColour parentBgColour)
 {
-    if(m_tips.empty()) return;
+    if(m_tips.empty())
+        return;
 
     m_point = pt;
     m_lineHeight = lineHeight;
@@ -243,7 +274,8 @@ void clEditorTipWindow::Activate(wxPoint pt, int lineHeight, wxColour parentBgCo
 void clEditorTipWindow::Deactivate()
 {
     Clear();
-    if(IsShown()) Hide();
+    if(IsShown())
+        Hide();
 }
 
 wxSize clEditorTipWindow::DoGetTipSize()
@@ -260,23 +292,44 @@ wxSize clEditorTipWindow::DoGetTipSize()
         dc = (wxDC*)&gdc;
     }
 
-    wxSize sz;
-    wxSize sz2;
-    dc->SetFont(m_font);
-    sz = dc->GetTextExtent(m_tipText);
-    if(GetTip() && GetTip()->Count() > 1) {
-        // for multiple tips, use second line as well
-        sz2 = dc->GetTextExtent(wxT("100 of 100"));
-        sz.y *= 2;
-    } else {
-        sz2 = wxSize(1, 1);
+    wxFont f = m_font;
+    f.SetWeight(wxFONTWEIGHT_BOLD);
+
+    dc->SetFont(f);
+    wxSize helperTextSize = dc->GetTextExtent("Tp");
+
+    int lineHeight = helperTextSize.y;
+    int minLineWidth = wxNOT_FOUND;
+    if(!m_footer.IsEmpty()) {
+        // Multiple signatures
+        minLineWidth = dc->GetTextExtent(m_footer).x;
+    }
+    if(!m_header.IsEmpty()) {
+        wxSize headerSize = dc->GetTextExtent(m_header);
+        minLineWidth = headerSize.x > minLineWidth ? headerSize.x : minLineWidth;
     }
 
-    sz.y += (2 * TIP_SPACER);
+    minLineWidth += (2 * TIP_SPACER);
+    wxString tipContent = wxJoin(m_args, '\n');
+    tipContent.Trim().Trim(false);
+
+    wxSize sz;
+    wxSize sz2;
+    sz = dc->GetMultiLineTextExtent(tipContent);
+
+    // add spacers
+    sz.y = (m_args.size() * lineHeight);
     sz.x += (2 * TIP_SPACER);
 
-    if(sz.x < sz2.x) {
-        sz.x = sz2.x;
+    if(sz.x < minLineWidth) {
+        sz.x = minLineWidth;
+    }
+
+    if(!m_footer.IsEmpty()) {
+        sz.y += lineHeight;
+    }
+    if(!m_header.IsEmpty()) {
+        sz.y += lineHeight;
     }
     return sz;
 }
@@ -294,8 +347,6 @@ void clEditorTipWindow::DoAdjustPosition()
     wxSize sz = DoGetTipSize();
     wxRect parentSize = GetParent()->GetClientRect();
 
-    // by default place the tip below the caret
-
     if(pt.y + m_lineHeight + sz.y > parentSize.height) {
         pt.y -= sz.y;
 
@@ -307,7 +358,8 @@ void clEditorTipWindow::DoAdjustPosition()
         // our tip can not fit into the screen, shift it left
         pt.x -= ((pt.x + sz.x) - parentSize.width);
 
-        if(pt.x < 0) pt.x = 0;
+        if(pt.x < 0)
+            pt.x = 0;
     }
     Move(pt);
 }
@@ -337,3 +389,64 @@ void clEditorTipWindow::OnEditoConfigChanged(clCommandEvent& e)
     m_font = EditorConfigST::Get()->GetLexer("C++")->GetFontForSyle(wxSTC_STYLE_CALLTIP);
     Refresh();
 }
+
+void clEditorTipWindow::DoMakeMultipleLineTip()
+{
+    // Find the open brace first
+    m_args.Clear();
+    m_footer.Clear();
+    m_header.Clear();
+
+    wxString sig = m_tipText.AfterFirst('(');
+    wxString returnValue = m_tipText.BeforeFirst('(');
+    returnValue.Trim().Trim(false);
+    if(returnValue.EndsWith(":")) {
+        returnValue.RemoveLast();
+        returnValue.Trim().Trim(false);
+        m_header << "RETURNS:  " << returnValue;
+    }
+
+    sig = sig.BeforeLast(')');
+    sig.Trim().Trim(false);
+    if(sig.IsEmpty()) {
+        m_args.Add("()");
+        if(GetTip() && (GetTip()->Count() > 1)) {
+            m_footer << GetTip()->GetCurr() << " OF " << GetTip()->Count();
+        }
+        return;
+    }
+
+    int depth = 0;
+    wxString currentArg;
+    for(size_t i = 0; i < sig.length(); ++i) {
+        wxChar ch = sig.at(i);
+        if(ch == '<' || ch == '[' || ch == '{' || ch == '(') {
+            ++depth;
+            currentArg << ch;
+        } else if(ch == '>' || ch == ']' || ch == '}' || ch == ')') {
+            --depth;
+            currentArg << ch;
+            if(depth < 0) {
+                // a parsing error
+                m_tipText.Clear();
+                m_args.Clear();
+                return;
+            }
+        } else if(ch == ',' && (depth == 0)) {
+            currentArg.Trim().Trim(false);
+            m_args.Add(currentArg);
+            currentArg.Clear();
+        } else {
+            currentArg << ch;
+        }
+    }
+
+    if(!currentArg.IsEmpty()) {
+        currentArg.Trim().Trim(false);
+        m_args.Add(currentArg);
+    }
+
+    if(GetTip() && (GetTip()->Count() > 1)) {
+        m_footer << GetTip()->GetCurr() << " OF " << GetTip()->Count();
+    }
+}
