@@ -41,45 +41,43 @@
 #include "cl_command_event.h"
 #include "ICompilerLocator.h"
 
-CleanRequest::CleanRequest(const QueueCommand &info)
+CleanRequest::CleanRequest(const QueueCommand& info)
     : ShellCommand(info)
 {
 }
 
 CleanRequest::~CleanRequest()
 {
-    //no need to delete the process, it will be deleted by the wx library
+    // no need to delete the process, it will be deleted by the wx library
 }
 
-
-//do the actual cleanup
-void CleanRequest::Process(IManager *manager)
+// do the actual cleanup
+void CleanRequest::Process(IManager* manager)
 {
     wxString cmd;
     wxString errMsg;
     wxStringMap_t om;
 
-    BuildSettingsConfig *bsc(manager ? manager->GetBuildSettingsConfigManager() : BuildSettingsConfigST::Get());
-    BuildManager *       bm(manager ? manager->GetBuildManager() : BuildManagerST::Get());
-    Workspace *          w(manager ? manager->GetWorkspace() : WorkspaceST::Get());
-
+    BuildSettingsConfig* bsc(manager ? manager->GetBuildSettingsConfigManager() : BuildSettingsConfigST::Get());
+    BuildManager* bm(manager ? manager->GetBuildManager() : BuildManagerST::Get());
+    Workspace* w(manager ? manager->GetWorkspace() : WorkspaceST::Get());
 
     ProjectPtr proj = w->FindProjectByName(m_info.GetProject(), errMsg);
-    if (!proj) {
+    if(!proj) {
         AppendLine(_("Cant find project: ") + m_info.GetProject());
         return;
     }
-    wxString             pname (proj->GetName());
+    wxString pname(proj->GetName());
 
-    //BuilderPtr builder = bm->GetBuilder(wxT("GNU makefile for g++/gcc"));
+    // BuilderPtr builder = bm->GetBuilder(wxT("GNU makefile for g++/gcc"));
     BuilderPtr builder = bm->GetSelectedBuilder();
-    if (m_info.GetProjectOnly()) {
+    if(m_info.GetProjectOnly()) {
         cmd = builder->GetPOCleanCommand(m_info.GetProject(), m_info.GetConfiguration());
     } else {
         cmd = builder->GetCleanCommand(m_info.GetProject(), m_info.GetConfiguration());
     }
 
-    if ( cmd.IsEmpty() ) {
+    if(cmd.IsEmpty()) {
         AppendLine(_("Sorry, there is no 'Clean' command available\n"));
         return;
     }
@@ -87,13 +85,21 @@ void CleanRequest::Process(IManager *manager)
     BuildConfigPtr bldConf = w->GetProjBuildConf(m_info.GetProject(), m_info.GetConfiguration());
     if(bldConf) {
         wxString cmpType = bldConf->GetCompilerType();
-        if (bldConf) {
+        if(bldConf) {
             wxString cmpType = bldConf->GetCompilerType();
             CompilerPtr cmp = bsc->GetCompiler(cmpType);
-            if (cmp) {
+            if(cmp) {
                 // Add the 'bin' folder of the compiler to the PATH environment variable
                 wxFileName cxx = cmp->GetTool("CXX");
-                om["PATH"] = wxString() << cxx.GetPath() << clPATH_SEPARATOR << "$PATH";
+                wxString pathvar;
+                pathvar << cxx.GetPath() << clPATH_SEPARATOR;
+
+                // If we have an additional path, add it as well
+                if(!cmp->GetPathVariable().IsEmpty()) {
+                    pathvar << cmp->GetPathVariable() << clPATH_SEPARATOR;
+                }
+                pathvar << "$PATH";
+                om["PATH"] = pathvar;
             }
         }
     } else {
@@ -103,15 +109,15 @@ void CleanRequest::Process(IManager *manager)
 
     // Notify plugins that a compile process is going to start
     clBuildEvent event(wxEVT_BUILD_STARTING);
-    event.SetProjectName( pname );
-    event.SetConfigurationName( m_info.GetConfiguration() );
-    
-    if (EventNotifier::Get()->ProcessEvent(event)) {
+    event.SetProjectName(pname);
+    event.SetConfigurationName(m_info.GetConfiguration());
+
+    if(EventNotifier::Get()->ProcessEvent(event)) {
         // the build is being handled by some plugin, no need to build it
         // using the standard way
         return;
     }
-    
+
     SendStartMsg();
     // Expand the variables of the command
     cmd = ExpandAllVariables(cmd, w, m_info.GetProject(), m_info.GetConfiguration(), wxEmptyString);
@@ -119,11 +125,11 @@ void CleanRequest::Process(IManager *manager)
     DirSaver ds;
     DoSetWorkingDirectory(proj, false, false);
 
-    if (m_info.GetProjectOnly() ) {
-        //need to change directory to project dir
+    if(m_info.GetProjectOnly()) {
+        // need to change directory to project dir
         wxSetWorkingDirectory(proj->GetFileName().GetPath());
     }
-    //print the build command
+    // print the build command
     AppendLine(cmd + wxT("\n"));
 
     // print the prefix message of the build start. This is important since the parser relies
@@ -131,20 +137,20 @@ void CleanRequest::Process(IManager *manager)
     if(m_info.GetProjectOnly()) {
         wxString configName(m_info.GetConfiguration());
 
-        //also, send another message to the main frame, indicating which project is being built
-        //and what configuration
+        // also, send another message to the main frame, indicating which project is being built
+        // and what configuration
         wxString text;
         text << wxGetTranslation(CLEAN_PROJECT_PREFIX) << m_info.GetProject() << wxT(" - ") << configName << wxT(" ]");
         text << wxT("----------\n");
         AppendLine(text);
     }
 
-    //apply environment settings
+    // apply environment settings
     EnvSetter env(NULL, &om, proj->GetName());
     m_proc = CreateAsyncProcess(this, cmd);
-    if ( !m_proc ) {
+    if(!m_proc) {
 
-        //remove environment settings applied
+        // remove environment settings applied
         wxString message;
         message << _("Failed to start clean process, command: ") << cmd << _(", process terminated with exit code: 0");
         AppendLine(message);
