@@ -46,7 +46,7 @@ BEGIN_EVENT_TABLE(OpenResourceDialog, OpenResourceDialogBase)
 EVT_TIMER(XRCID("OR_TIMER"), OpenResourceDialog::OnTimer)
 END_EVENT_TABLE()
 
-OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, const wxString & initialSelection)
+OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, const wxString& initialSelection)
     : OpenResourceDialogBase(parent)
     , m_manager(manager)
     , m_needRefresh(false)
@@ -85,7 +85,8 @@ OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, cons
     m_textCtrlResourceName->SetFocus();
     SetLabel(_("Open resource..."));
 
-    WindowAttrManager::Load(this, wxT("OpenResourceDialog"), m_manager->GetConfigTool());
+    SetName("OpenResourceDialog");
+    WindowAttrManager::Load(this);
 
     // load all files from the workspace
     if(m_manager->IsWorkspaceOpen()) {
@@ -125,8 +126,7 @@ OpenResourceDialog::OpenResourceDialog(wxWindow* parent, IManager* manager, cons
 OpenResourceDialog::~OpenResourceDialog()
 {
     m_timer->Stop();
-    delete m_timer;
-    WindowAttrManager::Save(this, wxT("OpenResourceDialog"), m_manager->GetConfigTool());
+    wxDELETE(m_timer);
 }
 
 void OpenResourceDialog::OnText(wxCommandEvent& event)
@@ -277,7 +277,7 @@ void OpenResourceDialog::DoPopulateWorkspaceFile()
         std::multimap<wxString, wxString>::iterator iter = m_files.begin();
         for(; iter != m_files.end(); iter++) {
 
-            if(!MatchesFilter(iter->first)) continue;
+            if(!MatchesFilter(iter->second)) continue;
 
             wxFileName fn(iter->second);
             FileExtManager::FileType type = FileExtManager::GetType(fn.GetFullName());
