@@ -39,8 +39,7 @@
 #include <map>
 #include "cl_config.h"
 
-struct GitLabelCommand
-{
+struct GitLabelCommand {
     GitLabelCommand() {}
 
     GitLabelCommand(const wxString& l, const wxString& c)
@@ -116,12 +115,12 @@ class GitEntry : public clConfigItem
     int m_gitConsoleSashPos;
     int m_gitCommitDlgHSashPos;
     int m_gitCommitDlgVSashPos;
-
+    wxArrayString m_recentCommits;
+    
 public:
     enum { Git_Verbose_Log = 0x00000001, Git_Show_Terminal = 0x00000002, Git_Colour_Tree_View = 0x00000004 };
 
-    struct GitProperties
-    {
+    struct GitProperties {
         wxString global_username;
         wxString global_email;
         wxString local_username;
@@ -147,7 +146,9 @@ public:
 
     void Save();
     GitEntry& Load();
-
+    wxArrayString& GetRecentCommit() { return m_recentCommits; }
+    void AddRecentCommit(const wxString& commitMessage);
+    
     void SetGitCommitDlgHSashPos(int gitCommitDlgHSashPos) { this->m_gitCommitDlgHSashPos = gitCommitDlgHSashPos; }
     void SetGitCommitDlgVSashPos(int gitCommitDlgVSashPos) { this->m_gitCommitDlgVSashPos = gitCommitDlgVSashPos; }
     int GetGitCommitDlgHSashPos() const { return m_gitCommitDlgHSashPos; }
